
Tutorial / Examples
===================

DOCUMENTATION COMING SOON

1. Hello World
--------------

Download example code from :download:`[here]<snippets/hello_world.py>`

.. include:: snippets/hello_world.py_

2. Parent/Child Structure
-------------------------

Download example code from :download:`[here]<snippets/parent_child.py>`

.. include:: snippets/parent_child.py_

3. TCP Server
-------------

- Download server example code from :download:`[here]<snippets/example_server.py>`
- Download client side code from :download:`[here]<snippets/client.py>`

.. include:: snippets/example_server.py_


4. Data Streaming TCP Server
----------------------------

- Download example code from :download:`[here]<snippets/example_server2.py>`
- Download client side code from :download:`[here]<snippets/client2.py>`

.. include:: snippets/example_server2.py_

